==> revechat_livechat_solution-7.x-1.7.tar.gz: revechat_livechat_solution/admin/js/revechat_admin.js <==
/**
 * @file
 * Created by ifte on 3/9/2016.
 */

(function ($) {
  'use strict';
  var reveChatBaseURL = 'https://dashboard.revechat.com/';
  
  window.ExistingAccoutVerify = function (response) {
     console.log(`response`,response);

     if (response.error)
     {
         $('#revechat_already_have .ajax_message').removeClass('wait').addClass('message alert').html(Drupal.t('Incorrect REVE Chat login.'));
         $('#edit-revechat-account-email').focus();
         return false;
     }
     else
     {
         if( response.data.account_id ) {
             
             $('input[name=revechat_aid]').val(response.data.account_id);
             $('#revechat-admin-settings-form').submit();

         } else {
             console.log(`Response Error: `,response);
         }
     }
  }
  var ReveChat = {
    init: function () {
      this.toggleForms();
      this.bindFormSubmit();
    },
    toggleForms: function () {
      var toggleForms = function () {
        if ($('#new_revechat_account').is(':checked')) {
          $('#revechat_already_have').hide();
          $('#revechat_new_account').show();
          $('#edit-name').focus();
        }
        else if ($('#has_revechat_account').is(':checked')) {
          $('#revechat_new_account').hide();
          $('#revechat_already_have').show();
          $('#edit-revechat-account-email').focus();
        }
      };
      toggleForms();
      $('#revechat_choose_form input').click(toggleForms);
    },
    bindFormSubmit: function () {
      $('#revechat-admin-settings-form').submit(function () {

        if (((parseInt($('input[name=revechat_aid]').val()) !== 0)) || $('#has_revechat_account').is(':checked')) {
          return ReveChat.alreadyHaveAccountForm();
        }
        else {
          return ReveChat.newLicenseForm();
        }

      });
    },
    alreadyHaveAccountForm: function () {
      if (this.validEmail()) {
        if ((parseInt($('input[name=revechat_aid]').val()) === 0)) {
          var login = $.trim($('#edit-revechat-account-email').val());
          if (!login.length) {
            $('#edit-revechat-account-email').focus();
            return false;
          }
          $('#revechat_already_have .ajax_message').removeClass('message').addClass('wait').html(Drupal.t('Please wait&hellip;'));
          var signInUrl = reveChatBaseURL + 'license/adminId/' + $('#edit-revechat-account-email').val() + '/?callback=window.ExistingAccoutVerify';


          $.ajax({
              type: 'GET',
              dataType: "text",
              // dataType: "jsonp",
              url: signInUrl, 
              // jsonpCallback: "window.ExistingAccoutVerify",
              beforeSend: function() {
              },
              success: function(response) {
                  eval(response);
              },
              error: function(XMLHttpRequest, textStatus, errorThrown) {
                  console.log("Error:1656");
              }

          }); // end of ajax saving.

          return false;
        }
      }
      else {
        $('#revechat_already_have .ajax_message').removeClass('wait').addClass('message alert').html(Drupal.t('Invalid Email.'));
        $('#edit-revechat-account-email').focus();
        return false;
      }
      return true;
    },
    newLicenseForm: function () {
      if (parseInt(($('input[name=revechat_aid]').val()) > 0)) {
        return true;
      }

      if (this.validateNewLicenseForm()) {
        $('#revechat_new_account .ajax_message').removeClass('message').addClass('wait').html(Drupal.t('Please wait...'));

        ReveChat.createLicense();
      }
      return false;
    },
    createLicense: function () {

      $('#revechat_new_account .ajax_message').removeClass('message').addClass('wait').html(Drupal.t('Creating new account&hellip;'));

      var signUpUrl = reveChatBaseURL + 'revechat/cms/api/signup.do';

      var name = $.trim($('#edit-name').val());
      var email = $.trim($('#edit-email').val());
      var password = $.trim($('#edit-accountpassword').val());
      var rePassword = $.trim($('#edit-retypepassword').val());
      var phone = $.trim($('#edit-phone').val());
      var website = $.trim($('#edit-website').val());


      $.ajax({
        data: {
          firstname: name,
          lastname: ' ',
          mailAddr: email,
          'password':password,   
          'phoneNo':phone,
          'companyWebsite':website,
          'utm_source':'cms',
          'utm_content':'drupal7',
          'referrer':'https://www.drupal.org/' 
        },
        type: 'POST',
        url: signUpUrl,
        dataType: 'json',
        cache: false,
        success: function (response) {


          ReveChat.removeAlert();
          if( void 0 != response.accountId) {
            $('input[name=revechat_aid]').val(response.accountId);
            $('#revechat-admin-settings-form').submit();
          } else {
              console.log(`Response Error: `,response);
              alert(response.message);
          }

        }
      });
    },
    validEmail: function () {

      if ($('#edit-submit').val() !== 'Remove') {
        if (/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,6}$/i.test($('#edit-revechat-account-email').val()) === false) {
          $('#edit-email').focus();
          return false;
        }
      }
      return true;
    },
    validateNewLicenseForm: function () {
      
      var name = $.trim($('#edit-name').val());
      var email = $.trim($('#edit-email').val());
      var password = $.trim($('#edit-accountpassword').val());
      var rePassword = $.trim($('#edit-retypepassword').val());

      // validate the form
      if(!name.length)
      {
          ReveChat.removeAlert();
          alert('Please please provide your full name');
          return false;
      }

      if(!ReveChat.isValidEmailAddress(email))
      {
          ReveChat.removeAlert();
          alert('Please please provide valid email address');
          return false;
      }

      if(password.length < 6)
      {
          ReveChat.removeAlert();
          alert('Please please provide your password. The password must be at least 6 characters long.');
          return false;
      }

      if(!rePassword.length || password.length < 6)
      {
          ReveChat.removeAlert();
          alert('Please please retype your password.');
          return false;
      }

      if(password != rePassword)
      {
          ReveChat.removeAlert();
          alert('Password does not match the confirm password.');
          $('#edit-retypepassword').focus();
          return false;
      }
      return true;
    },
    isValidEmailAddress: function (emailAddress) {
        var pattern = /^([a-z\d!#$%&'*+\-\/=?^_`{|}~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+(\.[a-z\d!#$%&'*+\-\/=?^_`{|}~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+)*|"((([ \t]*\r\n)?[ \t]+)?([\x01-\x08\x0b\x0c\x0e-\x1f\x7f\x21\x23-\x5b\x5d-\x7e\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]|\\[\x01-\x09\x0b\x0c\x0d-\x7f\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))*(([ \t]*\r\n)?[ \t]+)?")@(([a-z\d\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]|[a-z\d\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF][a-z\d\-._~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]*[a-z\d\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])\.)+([a-z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]|[a-z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF][a-z\d\-._~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]*[a-z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])\.?$/i;
        return pattern.test(emailAddress);
    },
    removeAlert: function()
    {
        $('.ajax_message')
            .removeClass('wait')
            .removeClass('message')
            .removeClass('alert')
            .html('');
    }
  };

  $(document).ready(function () {
    ReveChat.init();
  });
})(jQuery);

==> revechat_livechat_solution-7.x-1.8.tar.gz: revechat_livechat_solution/admin/js/revechat_admin.js <==
/**
 * @file
 * Created by ifte on 3/9/2016.
 */

(function ($) {
  'use strict';
  var reveChatBaseURL = 'https://app.revechat.com/';
  
  window.ExistingAccoutVerify = function (response) {
     console.log(`response`,response);

     if (response.error)
     {
         $('#revechat_already_have .ajax_message').removeClass('wait').addClass('message alert').html(Drupal.t('Incorrect REVE Chat login.'));
         $('#edit-revechat-account-email').focus();
         return false;
     }
     else
     {
         if( response.data.account_id ) {
             
             $('input[name=revechat_aid]').val(response.data.account_id);
             $('#revechat-admin-settings-form').submit();

         } else {
             console.log(`Response Error: `,response);
         }
     }
  }
  var ReveChat = {
    init: function () {
      this.toggleForms();
      this.bindFormSubmit();
    },
    toggleForms: function () {
      var toggleForms = function () {
        if ($('#new_revechat_account').is(':checked')) {
          $('#revechat_already_have').hide();
          $('#revechat_new_account').show();
          $('#edit-name').focus();
        }
        else if ($('#has_revechat_account').is(':checked')) {
          $('#revechat_new_account').hide();
          $('#revechat_already_have').show();
          $('#edit-revechat-account-email').focus();
        }
      };
      toggleForms();
      $('#revechat_choose_form input').click(toggleForms);
    },
    bindFormSubmit: function () {
      $('#revechat-admin-settings-form').submit(function () {

        if (((parseInt($('input[name=revechat_aid]').val()) !== 0)) || $('#has_revechat_account').is(':checked')) {
          return ReveChat.alreadyHaveAccountForm();
        }
        else {
          return ReveChat.newLicenseForm();
        }

      });
    },
    alreadyHaveAccountForm: function () {
      if (this.validEmail()) {
        if ((parseInt($('input[name=revechat_aid]').val()) === 0)) {
          var login = $.trim($('#edit-revechat-account-email').val());
          if (!login.length) {
            $('#edit-revechat-account-email').focus();
            return false;
          }
          $('#revechat_already_have .ajax_message').removeClass('message').addClass('wait').html(Drupal.t('Please wait&hellip;'));
          var signInUrl = reveChatBaseURL + 'license/adminId/' + $('#edit-revechat-account-email').val() + '/?callback=window.ExistingAccoutVerify';


          $.ajax({
              type: 'GET',
              dataType: "text",
              // dataType: "jsonp",
              url: signInUrl, 
              // jsonpCallback: "window.ExistingAccoutVerify",
              beforeSend: function() {
              },
              success: function(response) {
                  eval(response);
              },
              error: function(XMLHttpRequest, textStatus, errorThrown) {
                  console.log("Error:1656");
              }

          }); // end of ajax saving.

          return false;
        }
      }
      else {
        $('#revechat_already_have .ajax_message').removeClass('wait').addClass('message alert').html(Drupal.t('Invalid Email.'));
        $('#edit-revechat-account-email').focus();
        return false;
      }
      return true;
    },
    newLicenseForm: function () {
      if (parseInt(($('input[name=revechat_aid]').val()) > 0)) {
        return true;
      }

      if (this.validateNewLicenseForm()) {
        $('#revechat_new_account .ajax_message').removeClass('message').addClass('wait').html(Drupal.t('Please wait...'));

        ReveChat.createLicense();
      }
      return false;
    },
    createLicense: function () {

      $('#revechat_new_account .ajax_message').removeClass('message').addClass('wait').html(Drupal.t('Creating new account&hellip;'));

      var signUpUrl = reveChatBaseURL + 'revechat/cms/api/signup.do';

      var name = $.trim($('#edit-name').val());
      var email = $.trim($('#edit-email').val());
      var password = $.trim($('#edit-accountpassword').val());
      var rePassword = $.trim($('#edit-retypepassword').val());
      var phone = $.trim($('#edit-phone').val());
      var website = $.trim($('#edit-website').val());


      $.ajax({
        data: {
          firstname: name,
          lastname: ' ',
          mailAddr: email,
          'password':password,   
          'phoneNo':phone,
          'companyWebsite':website,
          'utm_source':'cms',
          'utm_content':'drupal7',
          'referrer':'https://www.drupal.org/' 
        },
        type: 'POST',
        url: signUpUrl,
        dataType: 'json',
        cache: false,
        success: function (response) {


          ReveChat.removeAlert();
          if( void 0 != response.accountId) {
            $('input[name=revechat_aid]').val(response.accountId);
            $('#revechat-admin-settings-form').submit();
          } else {
              console.log(`Response Error: `,response);
              alert(response.message);
          }

        }
      });
    },
    validEmail: function () {

      if ($('#edit-submit').val() !== 'Remove') {
        if (/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,6}$/i.test($('#edit-revechat-account-email').val()) === false) {
          $('#edit-email').focus();
          return false;
        }
      }
      return true;
    },
    validateNewLicenseForm: function () {
      
      var name = $.trim($('#edit-name').val());
      var email = $.trim($('#edit-email').val());
      var password = $.trim($('#edit-accountpassword').val());
      var rePassword = $.trim($('#edit-retypepassword').val());

      // validate the form
      if(!name.length)
      {
          ReveChat.removeAlert();
          alert('Please please provide your full name');
          return false;
      }

      if(!ReveChat.isValidEmailAddress(email))
      {
          ReveChat.removeAlert();
          alert('Please please provide valid email address');
          return false;
      }

      if(password.length < 6)
      {
          ReveChat.removeAlert();
          alert('Please please provide your password. The password must be at least 6 characters long.');
          return false;
      }

      if(!rePassword.length || password.length < 6)
      {
          ReveChat.removeAlert();
          alert('Please please retype your password.');
          return false;
      }

      if(password != rePassword)
      {
          ReveChat.removeAlert();
          alert('Password does not match the confirm password.');
          $('#edit-retypepassword').focus();
          return false;
      }
      return true;
    },
    isValidEmailAddress: function (emailAddress) {
        var pattern = /^([a-z\d!#$%&'*+\-\/=?^_`{|}~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+(\.[a-z\d!#$%&'*+\-\/=?^_`{|}~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+)*|"((([ \t]*\r\n)?[ \t]+)?([\x01-\x08\x0b\x0c\x0e-\x1f\x7f\x21\x23-\x5b\x5d-\x7e\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]|\\[\x01-\x09\x0b\x0c\x0d-\x7f\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))*(([ \t]*\r\n)?[ \t]+)?")@(([a-z\d\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]|[a-z\d\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF][a-z\d\-._~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]*[a-z\d\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])\.)+([a-z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]|[a-z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF][a-z\d\-._~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]*[a-z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])\.?$/i;
        return pattern.test(emailAddress);
    },
    removeAlert: function()
    {
        $('.ajax_message')
            .removeClass('wait')
            .removeClass('message')
            .removeClass('alert')
            .html('');
    }
  };

  $(document).ready(function () {
    ReveChat.init();
  });
})(jQuery);
